@@ -16,15 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: power-management.c,v 1.7 2005/05/10 05:30:22 ryanl Exp $
+ $Id: power-management.c,v 1.14 2006/09/21 23:07:58 ryanl Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <stdio.h>
-
 #include <sys/file.h>
 #include <sys/ioctl.h>
 #include <sys/types.h>
@@ -39,10 +37,8 @@
 #include <time.h>
 #include <unistd.h>
 
-#include <panel-applet.h>
-#include <panel-applet-gconf.h>
-
 #include "battstat.h"
+#include "battstat-hal.h"
 
 #define ERR_ACPID _("Can't access ACPI events in /var/run/acpid.socket! "    \
                     "Make sure the ACPI subsystem is working and "           \
@@ -65,6 +61,9 @@
 
 static const char *apm_readinfo (BatteryStatus *status);
 static int pm_initialised;
+#ifdef HAVE_HAL
+static int using_hal;
+#endif
 
 /*
  * What follows is a series of platform-specific apm_readinfo functions
@@ -104,12 +103,6 @@ test_update_integer( GtkSpinButton *spin, gint *value )
   *value = gtk_spin_button_get_value_as_int( spin );
 }
 
-static void
-test_update_state( GtkComboBox *combo, BatteryState *state )
-{
-  *state = gtk_combo_box_get_active( combo );
-}
-
 static void
 initialise_test( void )
 {
@@ -121,21 +114,9 @@ initialise_test( void )
   test_status.present = TRUE;
   test_status.on_ac_power = FALSE;
   test_status.charging = FALSE;
-  test_status.state = BATTERY_HIGH;
 
   box = GTK_BOX( gtk_vbox_new( 5, FALSE ) );
 
-  gtk_box_pack_start_defaults( box, gtk_label_new( "state" ) );
-  w = gtk_combo_box_new_text();
-  gtk_combo_box_append_text( GTK_COMBO_BOX( w ), "HIGH" );
-  gtk_combo_box_append_text( GTK_COMBO_BOX( w ), "LOW" );
-  gtk_combo_box_append_text( GTK_COMBO_BOX( w ), "CRITICAL" );
-  gtk_combo_box_append_text( GTK_COMBO_BOX( w ), "CHARGING" );
-  gtk_combo_box_set_active( GTK_COMBO_BOX( w ), BATTERY_HIGH );
-  g_signal_connect( G_OBJECT( w ), "changed",
-                    G_CALLBACK( test_update_state ), &test_status.state );
-  gtk_box_pack_start_defaults( box, w );
-  
   gtk_box_pack_start_defaults( box, gtk_label_new( "percent" ) );
   w = gtk_spin_button_new_with_range( -1.0, 100.0, 1 );
   gtk_spin_button_set_value( GTK_SPIN_BUTTON( w ), 50.0 );
@@ -188,8 +169,9 @@ apm_readinfo (BatteryStatus *status)
 }
 
 #undef __linux__
+#undef HAVE_HAL
 
-#elif __FreeBSD__
+#elif defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
 
 #include <machine/apm_bios.h>
 #include "acpi-freebsd.h"
@@ -239,9 +221,8 @@ apm_readinfo (BatteryStatus *status)
 
   status->present = TRUE;
   status->on_ac_power = apminfo.ai_acline ? 1 : 0;
-  status->state = apminfo.ai_batt_stat;
   status->percent = apminfo.ai_batt_life;
-  status->charging = (status->state == 3) ? TRUE : FALSE;
+  status->charging = (apminfo.ai_batt_stat) ? TRUE : FALSE;
   if (using_acpi)
     status->minutes = apminfo.ai_batt_time;
   else
@@ -284,9 +265,8 @@ apm_readinfo (BatteryStatus *status)
 
   status->present = TRUE;
   status->on_ac_power = apminfo.ac_state ? 1 : 0;
-  status->state = apminfo.battery_state;
   status->percent = apminfo.battery_life;
-  status->charging = (status->state == 3) ? TRUE : FALSE;
+  status->charging = (apminfo.battery_state == 3) ? TRUE : FALSE;
   status->minutes = apminfo.minutes_left;
 
   return NULL;
@@ -297,7 +277,7 @@ apm_readinfo (BatteryStatus *status)
 #include <apm.h>
 #include "acpi-linux.h"
 
-struct acpi_info acpiinfo;
+static struct acpi_info acpiinfo;
 static gboolean using_acpi;
 static int acpi_count;
 static int acpiwatch;
@@ -355,7 +335,6 @@ apm_readinfo (BatteryStatus *status)
 
   status->present = TRUE;
   status->on_ac_power = apminfo.ac_line_status ? 1 : 0;
-  status->state = apminfo.battery_status;
   status->percent = (guint) apminfo.battery_percentage;
   status->charging = (apminfo.battery_flags & 0x8) ? TRUE : FALSE;
   status->minutes = apminfo.battery_time;
@@ -370,7 +349,6 @@ apm_readinfo (BatteryStatus *status)
 {
   status->present = FALSE;
   status->on_ac_power = 1;
-  status->state = BATTERY_HIGH;
   status->percent = 100;
   status->charging = FALSE;
   status->minutes = 0;
@@ -402,7 +380,6 @@ power_management_getinfo( BatteryStatus *status )
   if( !pm_initialised )
   {
     status->on_ac_power = TRUE;
-    status->state = BATTERY_CRITICAL;
     status->minutes = -1;
     status->percent = 0;
     status->charging = FALSE;
@@ -411,14 +388,17 @@ power_management_getinfo( BatteryStatus *status )
     return NULL;
   }
 
+#ifdef HAVE_HAL
+  if( using_hal )
+  {
+    battstat_hal_get_battery_info( status );
+    return NULL;
+  }
+#endif
+
   retval = apm_readinfo( status );
 
-  if(status->state > 3) {
-    status->state = 0;
-    status->present = FALSE;
-  }
-
-  if(status->percent == (guint)-1) {
+  if(status->percent == -1) {
     status->percent = 0;
     status->present = FALSE;
   }
@@ -446,8 +426,28 @@ power_management_getinfo( BatteryStatus *status )
  * the problem might be.  This error message is not to be freed.
  */
 const char *
-power_management_initialise( void )
+power_management_initialise (int no_hal, void (*callback) (void))
 {
+#ifdef HAVE_HAL
+  char *err;
+
+  if( no_hal )
+    err = g_strdup( ":(" );
+  else
+    err = battstat_hal_initialise (callback);
+
+
+  if( err == NULL ) /* HAL is up */
+  {
+    pm_initialised = 1;
+    using_hal = TRUE;
+    return NULL;
+  }
+  else
+    /* fallback to legacy methods */
+    g_free( err );
+#endif
+    
 #ifdef __linux__
   struct stat statbuf;
 
@@ -473,7 +473,7 @@ power_management_initialise( void )
         G_IO_IN | G_IO_ERR | G_IO_HUP,
         acpi_callback, NULL);
   }
-#elif defined(__FreeBSD__)
+#elif defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
   if (acpi_freebsd_init(&acpiinfo)) {
     using_acpi = TRUE;
     acpi_count = 0;
@@ -494,6 +494,15 @@ power_management_initialise( void )
 void
 power_management_cleanup( void )
 {
+#ifdef HAVE_HAL
+  if( using_hal )
+  {
+    battstat_hal_cleanup();
+    pm_initialised = 1;
+    return;
+  }
+#endif
+
 #ifdef __linux__
   if (using_acpi)
   {
@@ -502,7 +511,7 @@ power_management_cleanup( void )
      acpiwatch = 0;
      acpi_linux_cleanup(&acpiinfo);
   }
-#elif defined(__FreeBSD__)
+#elif defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
   if (using_acpi) {
     acpi_freebsd_cleanup(&acpiinfo);
   }
@@ -510,3 +519,13 @@ power_management_cleanup( void )
 
   pm_initialised = 0;
 }
+
+int
+power_management_using_hal( void )
+{
+#ifdef HAVE_HAL
+  return using_hal;
+#else
+  return 0;
+#endif
+}
