@@ -15,12 +15,16 @@
  */
 
 #include "config.h"
-
-#include <gdk/gdkx.h>
-#include <gnome.h>
+#include <string.h>
 
 #include "gswitchit-applet.h"
 
+#include <glib.h>
+#include <gdk/gdkx.h>
+
+#include <panel-applet.h>
+
+
 static gboolean
 KeyboardAppletFactory (PanelApplet * applet,
 		       const gchar * iid, gpointer data)
